const fs = require('fs');
const country = require('./district-loaded');

const defaultCode = 100000;
const data = {};

data[defaultCode] = {};

country.forEach((province) => {
  if (/^香港/.test(province.name)) {
    province.districtList = [
      Object.assign(JSON.parse(JSON.stringify(province)), {
        adcode: '810100',
        name: '香港城区',
        level: 'city',
      }),
    ];
  } else if (/^澳门/.test(province.name)) {
    province.districtList = [
      Object.assign(JSON.parse(JSON.stringify(province)), {
        adcode: '820100',
        name: '澳门城区',
        level: 'city',
      }),
    ];
  }

  const provinces = province.districtList || province.districts;
  const provinceCode = Number(province.adcode);

  if (isNaN(provinceCode)) {
    console.log(`Invalid province code: ${provinceCode}`);
    return;
  }

  data[defaultCode][provinceCode] = province.name;

  if (Array.isArray(provinces)) {
    data[provinceCode] = {};

    provinces.forEach((city) => {
      const cities = city.districtList || city.districts;
      const cityCode = Number(city.adcode);

      if (isNaN(cityCode)) {
        console.log(`Invalid city code: ${cityCode}`);
        return;
      }

      if (city.level !== 'city') {
        console.log(`Invalid city level: ${city.level}`);
        return;
      }

      data[provinceCode][cityCode] = city.name;

      if (Array.isArray(cities)) {
        data[cityCode] = {};

        cities.forEach((district) => {
          let districtCode = Number(district.adcode);

          if (isNaN(districtCode)) {
            console.log(`Invalid district code: ${districtCode}`);
            return;
          }

          if (district.level !== 'district') {
            console.log(`Invalid district level: ${district.level}`);
            return;
          }

          districtCode = String(districtCode).replace(/^(8(?:1|2)0)0/, '$11');
          data[cityCode][districtCode] = district.name;
        });

        if (!Object.keys(data[cityCode]).length) {
          delete data[cityCode];
          console.log('Deleted empty city: ', city.name);
        }
      } else {
        data[cityCode] = {
          [cityCode]: city.name,
        };
      }
    });
  }
});

let output = JSON.stringify(data, false, 2);

output = output.replace(/"(\d+)"/g, '$1');
output = output.replace(/(")(\s+\})/g, '$1,$2');
output = output.replace(/"/g, '\'');
output = `export default ${output};`;

fs.writeFileSync('./district.data.js', output);
